OC.L10N.register(
    "text",
    {
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Učitana datoteka premašuje maksimalnu dopuštenu veličinu datoteke MAX_FILE_SIZE navedenu u HTML formi",
    "No file was uploaded" : "Nijedna datoteka nije učitana.",
    "Missing a temporary folder" : "Nedostaje privremeni direktorij.",
    "File not found" : "Datoteka nije pronađena",
    "guest" : "gost",
    "Saved" : "Spremljeno",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Link" : "Veza",
    "Cancel" : "Odustani",
    "Translate" : "Translate",
    "to" : "do",
    "Upload" : "Učitaj",
    "Edit" : "Izmjeni",
    "Choose" : "Izaberite"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
